@@ -456,6 +456,53 @@ var httpRequestMixin = {
                 },
             }).done(successCallback).fail(failureCallback);
         },
+        /** This method generates a DELETE HTTP request to `url` with a query
+            string built of a `queryParams` dictionnary.
+
+            It supports the following prototypes:
+
+            - reqDELETE(url)
+            - reqDELETE(url, successCallback)
+            - reqDELETE(url, successCallback, failureCallback)
+
+            `successCallback` and `failureCallback` must be Javascript
+            functions (i.e. instance of type `Function`).
+        */
+        reqMultiple: function(queryArray, successCallback, failureCallback) {
+            var vm = this;
+            var ajaxCalls = [];
+            if( !successCallback ) {
+                successCallback = function() {};
+            }
+            if( !failureCallback ) {
+                failureCallback = showErrorMessages;
+            }
+            for(var idx = 0; idx < queryArray.length; ++idx ) {
+                ajaxCalls.push(function () {
+                    return $.ajax({
+                        method: queryArray[idx].method,
+                        url: queryArray[idx].url,
+                        data: JSON.stringify(queryArray[idx].data),
+                        beforeSend: function(xhr, settings) {
+                            var authToken = vm._getAuthToken();
+                            if( authToken ) {
+                                xhr.setRequestHeader("Authorization",
+                                                     "Bearer " + authToken);
+                            } else {
+                                if( !vm._csrfSafeMethod(settings.type) ) {
+                                    var csrfToken = vm._getCSRFToken();
+                                    if( csrfToken ) {
+                                        xhr.setRequestHeader("X-CSRFToken", csrfToken);
+                                    }
+                                }
+                            }
+                        },
+                        contentType: 'application/json',
+                    });
+                }());
+            }
+            jQuery.when(ajaxCalls).done(successCallback).fail(failureCallback);
+        },
     }
 }
 
@@ -538,7 +585,7 @@ var paginationMixin = {
             params: {
                 page: 1,
             },
-            itemsPerPage: djaodjinSettings.itemsPerPage,
+            itemsPerPage: this.$itemsPerPage,
             getCompleteCb: 'getCompleted',
             getBeforeCb: 'resetPage',
             qsCache: null,
@@ -604,9 +651,9 @@ var paginationMixin = {
 
 var sortableMixin = {
     data: function(){
-        var defaultDir = djaodjinSettings.sortDirection || 'desc';
+        var defaultDir = this.$sortDirection || 'desc';
         var dir = (defaultDir === 'desc') ? DESC_SORT_PRE : '';
-        var o = djaodjinSettings.sortByField || 'created_at';
+        var o = this.$sortByField || 'created_at';
         return {
             params: {
                 o: dir + o,
@@ -697,19 +744,19 @@ var sortableMixin = {
 
 
 var itemListMixin = {
-    data: function(){
-        return this.getInitData();
-    },
     mixins: [
         httpRequestMixin,
         paginationMixin,
         filterableMixin,
         sortableMixin
     ],
+    data: function(){
+        return this.getInitData();
+    },
     methods: {
         getInitData: function(){
             var data = {
-                url: '',
+                url: null,
                 itemsLoaded: false,
                 items: {
                     results: [],
@@ -721,18 +768,20 @@ var itemListMixin = {
                     // as oppossed to `moment` or `Date` objects because this
                     // is how uiv-date-picker will update them.
                     start_at: null,
-                    ends_at: null
+                    ends_at: null,
+                    // The timezone for both start_at and ends_at.
+                    timezone: 'local'
                 },
                 getCb: null,
                 getCompleteCb: null,
                 getBeforeCb: null,
             }
-            if( djaodjinSettings.date_range ) {
-                if( djaodjinSettings.date_range.start_at ) {
+            if( this.$dateRange ) {
+                if( this.$dateRange.start_at ) {
                     data.params['start_at'] = moment(
-                        djaodjinSettings.date_range.start_at).format(DATE_FORMAT);
+                        this.$dateRange.start_at).format(DATE_FORMAT);
                 }
-                if( djaodjinSettings.date_range.ends_at ) {
+                if( this.$dateRange.ends_at ) {
                     // uiv-date-picker will expect ends_at as a String
                     // but DATE_FORMAT will literally cut the hour part,
                     // regardless of timezone. We don't want an empty list
@@ -740,7 +789,10 @@ var itemListMixin = {
                     // If we use moment `endOfDay` we get 23:59:59 so we
                     // add a full day instead.
                     data.params['ends_at'] = moment(
-                        djaodjinSettings.date_range.ends_at).add(1,'days').format(DATE_FORMAT);
+                        this.$dateRange.ends_at).add(1,'days').format(DATE_FORMAT);
+                }
+                if( this.$dateRange.timezone ) {
+                    data.params['timezone'] = this.$dateRange.timezone;
                 }
             }
             return data;
